LightReady

Struct LightReady 

pub struct LightReady { /* private fields */ }
LightReady encapsulates the commit index, committed entries and messages that are ready to be applied or be sent to other peers.

Implementations

Source

impl LightReady

pub fn commit_index(&self) -> Option<u64>

The current commit index. It will be None state if there is no update. It is not required to save it to stable storage.

pub fn committed_entries(&self) -> &Vec<Entry>

CommittedEntries specifies entries to be committed to a store/state-machine. These have previously been committed to stable store.

pub fn take_committed_entries(&mut self) -> Vec<Entry>

Take the CommitEntries.

pub fn messages(&self) -> &[Message]

Messages specifies outbound messages to be sent.

pub fn take_messages(&mut self) -> Vec<Message>

Take the Messages.